package exceptions;

import javax.swing.*;
import java.awt.Graphics;

public class Panneau extends JPanel {
  private Forme forme = new Cercle(50, 50, 100);

  protected void paintComponent(Graphics g) {
    super.paintComponent(g);
    forme.dessine(g);
  }
  public void setXForme(int x) throws ErreurFormeX, ErreurFormeXNegatif {
    if (x<0) throw new ErreurFormeXNegatif(x);
    if ((x < forme.getDimension()/2) || (x > getWidth()-forme.getDimension()/2))
      throw new ErreurFormeX(x);
    forme.setX(x);
    repaint();
  }
  public void setYForme(int y) throws ErreurFormeY, ErreurFormeYNegatif {
    if (y<0) throw new ErreurFormeYNegatif(y);
    if ((y < forme.getDimension()/2) || (y > getHeight()-forme.getDimension()/2))
      throw new ErreurFormeY(y);
    forme.setY(y);
    repaint();
  }
  public void setDimensionForme(int dimension) throws ErreurFormeDimension, ErreurFormeDimensionNegatif {
    if (dimension<0) throw new ErreurFormeDimensionNegatif(dimension);
    if ((forme.getX() < dimension/2) ||
        (forme.getY() < dimension/2) ||
        (forme.getX() > getHeight()- dimension/2) ||
        (forme.getY() > getHeight()- dimension/2))
          throw new ErreurFormeDimension(dimension);
    forme.setDimension(dimension);
    repaint();
  }
  public void setForme(Class classe) {
    int x = forme.getX();
    int y = forme.getY();
    int dimension = forme.getDimension();
    if (classe == Cercle.class) forme = new Cercle(x, y, dimension);
    if (classe == Carr.class) forme = new Carr(x, y, dimension);
    repaint();
  }
  public int getXForme() { return forme.getX(); }
  public int getYForme() { return forme.getY(); }
  public int getDimensionForme() { return forme.getDimension(); }
}

class ErreurForme extends Exception {
  protected String message = "Erreur sur la forme : ";
  public String getMessage() { return message; }
}

class ErreurFormeX extends ErreurForme {
  private int x;
  ErreurFormeX(int x) {
    super();
    message += "Valeur de X : " + (this.x = x);
  }
  int getX() { return x; }
}

class ErreurFormeXNegatif extends ErreurFormeX {
  ErreurFormeXNegatif(int x) {
    super(x);
    message += " ngatif";
  }
}

class ErreurFormeYNegatif extends ErreurFormeY {
  ErreurFormeYNegatif(int y) {
    super(y);
    message += " ngatif";
  }
}

class ErreurFormeY extends ErreurForme {
  private int y;
  ErreurFormeY(int y) {
    super();
    message += "Valeur de Y : " + (this.y = y);
  }
  int getY() { return y; }
}

class ErreurFormeDimension extends ErreurForme {
  private int dimension;
  ErreurFormeDimension(int dimension) {
    super();
    message += "Dimension : " + (this.dimension = dimension);
  }
  int getDimension() { return dimension; }
}

class ErreurFormeDimensionNegatif extends ErreurFormeDimension {
  ErreurFormeDimensionNegatif(int dimension) {
    super(dimension);
    message += " ngatif";
  }
}
